pm4py.algo.comparison package
=============================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.algo.comparison.petrinet

Module contents
---------------

.. automodule:: pm4py.algo.comparison
   :members:
   :undoc-members:
   :show-inheritance:
